# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProviderArgs', 'Provider']

@pulumi.input_type
class ProviderArgs:
    def __init__(__self__, *,
                 auth: Optional[pulumi.Input[builtins.str]] = None,
                 ca_cert: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_access_policy_token: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_api_url: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_provider_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_provider_url: Optional[pulumi.Input[builtins.str]] = None,
                 connections_api_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 connections_api_url: Optional[pulumi.Input[builtins.str]] = None,
                 fleet_management_auth: Optional[pulumi.Input[builtins.str]] = None,
                 fleet_management_url: Optional[pulumi.Input[builtins.str]] = None,
                 frontend_o11y_api_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 http_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 insecure_skip_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 k6_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 k6_url: Optional[pulumi.Input[builtins.str]] = None,
                 oncall_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 oncall_url: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.int]] = None,
                 retries: Optional[pulumi.Input[builtins.int]] = None,
                 retry_status_codes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 retry_wait: Optional[pulumi.Input[builtins.int]] = None,
                 sm_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 sm_url: Optional[pulumi.Input[builtins.str]] = None,
                 stack_id: Optional[pulumi.Input[builtins.int]] = None,
                 store_dashboard_sha256: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_cert: Optional[pulumi.Input[builtins.str]] = None,
                 tls_key: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Provider resource.
        :param pulumi.Input[builtins.str] auth: API token, basic auth in the `username:password` format or `anonymous` (string literal). May alternatively be set via
               the `GRAFANA_AUTH` environment variable.
        :param pulumi.Input[builtins.str] ca_cert: Certificate CA bundle (file path or literal value) to use to verify the Grafana server's certificate. May alternatively
               be set via the `GRAFANA_CA_CERT` environment variable.
        :param pulumi.Input[builtins.str] cloud_access_policy_token: Access Policy Token for Grafana Cloud. May alternatively be set via the `GRAFANA_CLOUD_ACCESS_POLICY_TOKEN` environment
               variable.
        :param pulumi.Input[builtins.str] cloud_api_url: Grafana Cloud's API URL. May alternatively be set via the `GRAFANA_CLOUD_API_URL` environment variable.
        :param pulumi.Input[builtins.str] cloud_provider_access_token: A Grafana Cloud Provider access token. May alternatively be set via the `GRAFANA_CLOUD_PROVIDER_ACCESS_TOKEN`
               environment variable.
        :param pulumi.Input[builtins.str] cloud_provider_url: A Grafana Cloud Provider backend address. May alternatively be set via the `GRAFANA_CLOUD_PROVIDER_URL` environment
               variable.
        :param pulumi.Input[builtins.str] connections_api_access_token: A Grafana Connections API access token. May alternatively be set via the `GRAFANA_CONNECTIONS_API_ACCESS_TOKEN`
               environment variable.
        :param pulumi.Input[builtins.str] connections_api_url: A Grafana Connections API address. May alternatively be set via the `GRAFANA_CONNECTIONS_API_URL` environment variable.
        :param pulumi.Input[builtins.str] fleet_management_auth: A Grafana Fleet Management basic auth in the `username:password` format. May alternatively be set via the
               `GRAFANA_FLEET_MANAGEMENT_AUTH` environment variable.
        :param pulumi.Input[builtins.str] fleet_management_url: A Grafana Fleet Management API address. May alternatively be set via the `GRAFANA_FLEET_MANAGEMENT_URL` environment
               variable.
        :param pulumi.Input[builtins.str] frontend_o11y_api_access_token: A Grafana Frontend Observability API access token. May alternatively be set via the
               `GRAFANA_FRONTEND_O11Y_API_ACCESS_TOKEN` environment variable.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] http_headers: Optional. HTTP headers mapping keys to values used for accessing the Grafana and Grafana Cloud APIs. May alternatively
               be set via the `GRAFANA_HTTP_HEADERS` environment variable in JSON format.
        :param pulumi.Input[builtins.bool] insecure_skip_verify: Skip TLS certificate verification. May alternatively be set via the `GRAFANA_INSECURE_SKIP_VERIFY` environment variable.
        :param pulumi.Input[builtins.str] k6_access_token: The k6 Cloud API token. May alternatively be set via the `GRAFANA_K6_ACCESS_TOKEN` environment variable.
        :param pulumi.Input[builtins.str] k6_url: The k6 Cloud API url. May alternatively be set via the `GRAFANA_K6_URL` environment variable.
        :param pulumi.Input[builtins.str] oncall_access_token: A Grafana OnCall access token. May alternatively be set via the `GRAFANA_ONCALL_ACCESS_TOKEN` environment variable.
        :param pulumi.Input[builtins.str] oncall_url: An Grafana OnCall backend address. May alternatively be set via the `GRAFANA_ONCALL_URL` environment variable.
        :param pulumi.Input[builtins.int] org_id: The Grafana org ID, if you are using a self-hosted OSS or enterprise Grafana instance. May alternatively be set via the
               `GRAFANA_ORG_ID` environment variable.
        :param pulumi.Input[builtins.int] retries: The amount of retries to use for Grafana API and Grafana Cloud API calls. May alternatively be set via the
               `GRAFANA_RETRIES` environment variable.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] retry_status_codes: The status codes to retry on for Grafana API and Grafana Cloud API calls. Use `x` as a digit wildcard. Defaults to 429
               and 5xx. May alternatively be set via the `GRAFANA_RETRY_STATUS_CODES` environment variable.
        :param pulumi.Input[builtins.int] retry_wait: The amount of time in seconds to wait between retries for Grafana API and Grafana Cloud API calls. May alternatively be
               set via the `GRAFANA_RETRY_WAIT` environment variable.
        :param pulumi.Input[builtins.str] sm_access_token: A Synthetic Monitoring access token. May alternatively be set via the `GRAFANA_SM_ACCESS_TOKEN` environment variable.
        :param pulumi.Input[builtins.int] stack_id: The Grafana stack ID, if you are using a Grafana Cloud stack. May alternatively be set via the `GRAFANA_STACK_ID`
               environment variable.
        :param pulumi.Input[builtins.bool] store_dashboard_sha256: Set to true if you want to save only the sha256sum instead of complete dashboard model JSON in the tfstate.
        :param pulumi.Input[builtins.str] tls_cert: Client TLS certificate (file path or literal value) to use to authenticate to the Grafana server. May alternatively be
               set via the `GRAFANA_TLS_CERT` environment variable.
        :param pulumi.Input[builtins.str] tls_key: Client TLS key (file path or literal value) to use to authenticate to the Grafana server. May alternatively be set via
               the `GRAFANA_TLS_KEY` environment variable.
        :param pulumi.Input[builtins.str] url: The root URL of a Grafana server. May alternatively be set via the `GRAFANA_URL` environment variable.
        """
        if auth is None:
            auth = _utilities.get_env('GRAFANA_AUTH')
        if auth is not None:
            pulumi.set(__self__, "auth", auth)
        if ca_cert is None:
            ca_cert = _utilities.get_env('GRAFANA_CA_CERT')
        if ca_cert is not None:
            pulumi.set(__self__, "ca_cert", ca_cert)
        if cloud_access_policy_token is None:
            cloud_access_policy_token = _utilities.get_env('GRAFANA_CLOUD_ACCESS_POLICY_TOKEN')
        if cloud_access_policy_token is not None:
            pulumi.set(__self__, "cloud_access_policy_token", cloud_access_policy_token)
        if cloud_api_url is None:
            cloud_api_url = _utilities.get_env('GRAFANA_CLOUD_API_URL')
        if cloud_api_url is not None:
            pulumi.set(__self__, "cloud_api_url", cloud_api_url)
        if cloud_provider_access_token is not None:
            pulumi.set(__self__, "cloud_provider_access_token", cloud_provider_access_token)
        if cloud_provider_url is not None:
            pulumi.set(__self__, "cloud_provider_url", cloud_provider_url)
        if connections_api_access_token is not None:
            pulumi.set(__self__, "connections_api_access_token", connections_api_access_token)
        if connections_api_url is not None:
            pulumi.set(__self__, "connections_api_url", connections_api_url)
        if fleet_management_auth is not None:
            pulumi.set(__self__, "fleet_management_auth", fleet_management_auth)
        if fleet_management_url is not None:
            pulumi.set(__self__, "fleet_management_url", fleet_management_url)
        if frontend_o11y_api_access_token is not None:
            pulumi.set(__self__, "frontend_o11y_api_access_token", frontend_o11y_api_access_token)
        if http_headers is not None:
            pulumi.set(__self__, "http_headers", http_headers)
        if insecure_skip_verify is None:
            insecure_skip_verify = _utilities.get_env_bool('GRAFANA_INSECURE_SKIP_VERIFY')
        if insecure_skip_verify is not None:
            pulumi.set(__self__, "insecure_skip_verify", insecure_skip_verify)
        if k6_access_token is not None:
            pulumi.set(__self__, "k6_access_token", k6_access_token)
        if k6_url is not None:
            pulumi.set(__self__, "k6_url", k6_url)
        if oncall_access_token is None:
            oncall_access_token = _utilities.get_env('GRAFANA_ONCALL_ACCESS_TOKEN')
        if oncall_access_token is not None:
            pulumi.set(__self__, "oncall_access_token", oncall_access_token)
        if oncall_url is None:
            oncall_url = _utilities.get_env('GRAFANA_ONCALL_URL')
        if oncall_url is not None:
            pulumi.set(__self__, "oncall_url", oncall_url)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if retries is None:
            retries = _utilities.get_env_int('GRAFANA_RETRIES')
        if retries is not None:
            pulumi.set(__self__, "retries", retries)
        if retry_status_codes is not None:
            pulumi.set(__self__, "retry_status_codes", retry_status_codes)
        if retry_wait is None:
            retry_wait = _utilities.get_env_int('GRAFANA_RETRY_WAIT')
        if retry_wait is not None:
            pulumi.set(__self__, "retry_wait", retry_wait)
        if sm_access_token is None:
            sm_access_token = _utilities.get_env('GRAFANA_SM_ACCESS_TOKEN')
        if sm_access_token is not None:
            pulumi.set(__self__, "sm_access_token", sm_access_token)
        if sm_url is None:
            sm_url = _utilities.get_env('GRAFANA_SM_URL')
        if sm_url is not None:
            pulumi.set(__self__, "sm_url", sm_url)
        if stack_id is not None:
            pulumi.set(__self__, "stack_id", stack_id)
        if store_dashboard_sha256 is None:
            store_dashboard_sha256 = _utilities.get_env_bool('GRAFANA_STORE_DASHBOARD_SHA256')
        if store_dashboard_sha256 is not None:
            pulumi.set(__self__, "store_dashboard_sha256", store_dashboard_sha256)
        if tls_cert is None:
            tls_cert = _utilities.get_env('GRAFANA_TLS_CERT')
        if tls_cert is not None:
            pulumi.set(__self__, "tls_cert", tls_cert)
        if tls_key is None:
            tls_key = _utilities.get_env('GRAFANA_TLS_KEY')
        if tls_key is not None:
            pulumi.set(__self__, "tls_key", tls_key)
        if url is None:
            url = _utilities.get_env('GRAFANA_URL')
        if url is not None:
            pulumi.set(__self__, "url", url)

    @property
    @pulumi.getter
    def auth(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        API token, basic auth in the `username:password` format or `anonymous` (string literal). May alternatively be set via
        the `GRAFANA_AUTH` environment variable.
        """
        return pulumi.get(self, "auth")

    @auth.setter
    def auth(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "auth", value)

    @property
    @pulumi.getter(name="caCert")
    def ca_cert(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Certificate CA bundle (file path or literal value) to use to verify the Grafana server's certificate. May alternatively
        be set via the `GRAFANA_CA_CERT` environment variable.
        """
        return pulumi.get(self, "ca_cert")

    @ca_cert.setter
    def ca_cert(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ca_cert", value)

    @property
    @pulumi.getter(name="cloudAccessPolicyToken")
    def cloud_access_policy_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Access Policy Token for Grafana Cloud. May alternatively be set via the `GRAFANA_CLOUD_ACCESS_POLICY_TOKEN` environment
        variable.
        """
        return pulumi.get(self, "cloud_access_policy_token")

    @cloud_access_policy_token.setter
    def cloud_access_policy_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cloud_access_policy_token", value)

    @property
    @pulumi.getter(name="cloudApiUrl")
    def cloud_api_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Grafana Cloud's API URL. May alternatively be set via the `GRAFANA_CLOUD_API_URL` environment variable.
        """
        return pulumi.get(self, "cloud_api_url")

    @cloud_api_url.setter
    def cloud_api_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cloud_api_url", value)

    @property
    @pulumi.getter(name="cloudProviderAccessToken")
    def cloud_provider_access_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A Grafana Cloud Provider access token. May alternatively be set via the `GRAFANA_CLOUD_PROVIDER_ACCESS_TOKEN`
        environment variable.
        """
        return pulumi.get(self, "cloud_provider_access_token")

    @cloud_provider_access_token.setter
    def cloud_provider_access_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cloud_provider_access_token", value)

    @property
    @pulumi.getter(name="cloudProviderUrl")
    def cloud_provider_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A Grafana Cloud Provider backend address. May alternatively be set via the `GRAFANA_CLOUD_PROVIDER_URL` environment
        variable.
        """
        return pulumi.get(self, "cloud_provider_url")

    @cloud_provider_url.setter
    def cloud_provider_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cloud_provider_url", value)

    @property
    @pulumi.getter(name="connectionsApiAccessToken")
    def connections_api_access_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A Grafana Connections API access token. May alternatively be set via the `GRAFANA_CONNECTIONS_API_ACCESS_TOKEN`
        environment variable.
        """
        return pulumi.get(self, "connections_api_access_token")

    @connections_api_access_token.setter
    def connections_api_access_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connections_api_access_token", value)

    @property
    @pulumi.getter(name="connectionsApiUrl")
    def connections_api_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A Grafana Connections API address. May alternatively be set via the `GRAFANA_CONNECTIONS_API_URL` environment variable.
        """
        return pulumi.get(self, "connections_api_url")

    @connections_api_url.setter
    def connections_api_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connections_api_url", value)

    @property
    @pulumi.getter(name="fleetManagementAuth")
    def fleet_management_auth(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A Grafana Fleet Management basic auth in the `username:password` format. May alternatively be set via the
        `GRAFANA_FLEET_MANAGEMENT_AUTH` environment variable.
        """
        return pulumi.get(self, "fleet_management_auth")

    @fleet_management_auth.setter
    def fleet_management_auth(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "fleet_management_auth", value)

    @property
    @pulumi.getter(name="fleetManagementUrl")
    def fleet_management_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A Grafana Fleet Management API address. May alternatively be set via the `GRAFANA_FLEET_MANAGEMENT_URL` environment
        variable.
        """
        return pulumi.get(self, "fleet_management_url")

    @fleet_management_url.setter
    def fleet_management_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "fleet_management_url", value)

    @property
    @pulumi.getter(name="frontendO11yApiAccessToken")
    def frontend_o11y_api_access_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A Grafana Frontend Observability API access token. May alternatively be set via the
        `GRAFANA_FRONTEND_O11Y_API_ACCESS_TOKEN` environment variable.
        """
        return pulumi.get(self, "frontend_o11y_api_access_token")

    @frontend_o11y_api_access_token.setter
    def frontend_o11y_api_access_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "frontend_o11y_api_access_token", value)

    @property
    @pulumi.getter(name="httpHeaders")
    def http_headers(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Optional. HTTP headers mapping keys to values used for accessing the Grafana and Grafana Cloud APIs. May alternatively
        be set via the `GRAFANA_HTTP_HEADERS` environment variable in JSON format.
        """
        return pulumi.get(self, "http_headers")

    @http_headers.setter
    def http_headers(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "http_headers", value)

    @property
    @pulumi.getter(name="insecureSkipVerify")
    def insecure_skip_verify(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Skip TLS certificate verification. May alternatively be set via the `GRAFANA_INSECURE_SKIP_VERIFY` environment variable.
        """
        return pulumi.get(self, "insecure_skip_verify")

    @insecure_skip_verify.setter
    def insecure_skip_verify(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "insecure_skip_verify", value)

    @property
    @pulumi.getter(name="k6AccessToken")
    def k6_access_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The k6 Cloud API token. May alternatively be set via the `GRAFANA_K6_ACCESS_TOKEN` environment variable.
        """
        return pulumi.get(self, "k6_access_token")

    @k6_access_token.setter
    def k6_access_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "k6_access_token", value)

    @property
    @pulumi.getter(name="k6Url")
    def k6_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The k6 Cloud API url. May alternatively be set via the `GRAFANA_K6_URL` environment variable.
        """
        return pulumi.get(self, "k6_url")

    @k6_url.setter
    def k6_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "k6_url", value)

    @property
    @pulumi.getter(name="oncallAccessToken")
    def oncall_access_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A Grafana OnCall access token. May alternatively be set via the `GRAFANA_ONCALL_ACCESS_TOKEN` environment variable.
        """
        return pulumi.get(self, "oncall_access_token")

    @oncall_access_token.setter
    def oncall_access_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oncall_access_token", value)

    @property
    @pulumi.getter(name="oncallUrl")
    def oncall_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        An Grafana OnCall backend address. May alternatively be set via the `GRAFANA_ONCALL_URL` environment variable.
        """
        return pulumi.get(self, "oncall_url")

    @oncall_url.setter
    def oncall_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "oncall_url", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The Grafana org ID, if you are using a self-hosted OSS or enterprise Grafana instance. May alternatively be set via the
        `GRAFANA_ORG_ID` environment variable.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def retries(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The amount of retries to use for Grafana API and Grafana Cloud API calls. May alternatively be set via the
        `GRAFANA_RETRIES` environment variable.
        """
        return pulumi.get(self, "retries")

    @retries.setter
    def retries(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "retries", value)

    @property
    @pulumi.getter(name="retryStatusCodes")
    def retry_status_codes(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        The status codes to retry on for Grafana API and Grafana Cloud API calls. Use `x` as a digit wildcard. Defaults to 429
        and 5xx. May alternatively be set via the `GRAFANA_RETRY_STATUS_CODES` environment variable.
        """
        return pulumi.get(self, "retry_status_codes")

    @retry_status_codes.setter
    def retry_status_codes(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "retry_status_codes", value)

    @property
    @pulumi.getter(name="retryWait")
    def retry_wait(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The amount of time in seconds to wait between retries for Grafana API and Grafana Cloud API calls. May alternatively be
        set via the `GRAFANA_RETRY_WAIT` environment variable.
        """
        return pulumi.get(self, "retry_wait")

    @retry_wait.setter
    def retry_wait(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "retry_wait", value)

    @property
    @pulumi.getter(name="smAccessToken")
    def sm_access_token(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A Synthetic Monitoring access token. May alternatively be set via the `GRAFANA_SM_ACCESS_TOKEN` environment variable.
        """
        return pulumi.get(self, "sm_access_token")

    @sm_access_token.setter
    def sm_access_token(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sm_access_token", value)

    @property
    @pulumi.getter(name="smUrl")
    def sm_url(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "sm_url")

    @sm_url.setter
    def sm_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "sm_url", value)

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        The Grafana stack ID, if you are using a Grafana Cloud stack. May alternatively be set via the `GRAFANA_STACK_ID`
        environment variable.
        """
        return pulumi.get(self, "stack_id")

    @stack_id.setter
    def stack_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "stack_id", value)

    @property
    @pulumi.getter(name="storeDashboardSha256")
    def store_dashboard_sha256(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to true if you want to save only the sha256sum instead of complete dashboard model JSON in the tfstate.
        """
        return pulumi.get(self, "store_dashboard_sha256")

    @store_dashboard_sha256.setter
    def store_dashboard_sha256(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "store_dashboard_sha256", value)

    @property
    @pulumi.getter(name="tlsCert")
    def tls_cert(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Client TLS certificate (file path or literal value) to use to authenticate to the Grafana server. May alternatively be
        set via the `GRAFANA_TLS_CERT` environment variable.
        """
        return pulumi.get(self, "tls_cert")

    @tls_cert.setter
    def tls_cert(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tls_cert", value)

    @property
    @pulumi.getter(name="tlsKey")
    def tls_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Client TLS key (file path or literal value) to use to authenticate to the Grafana server. May alternatively be set via
        the `GRAFANA_TLS_KEY` environment variable.
        """
        return pulumi.get(self, "tls_key")

    @tls_key.setter
    def tls_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "tls_key", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The root URL of a Grafana server. May alternatively be set via the `GRAFANA_URL` environment variable.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("pulumi:providers:grafana")
class Provider(pulumi.ProviderResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth: Optional[pulumi.Input[builtins.str]] = None,
                 ca_cert: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_access_policy_token: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_api_url: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_provider_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_provider_url: Optional[pulumi.Input[builtins.str]] = None,
                 connections_api_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 connections_api_url: Optional[pulumi.Input[builtins.str]] = None,
                 fleet_management_auth: Optional[pulumi.Input[builtins.str]] = None,
                 fleet_management_url: Optional[pulumi.Input[builtins.str]] = None,
                 frontend_o11y_api_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 http_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 insecure_skip_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 k6_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 k6_url: Optional[pulumi.Input[builtins.str]] = None,
                 oncall_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 oncall_url: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.int]] = None,
                 retries: Optional[pulumi.Input[builtins.int]] = None,
                 retry_status_codes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 retry_wait: Optional[pulumi.Input[builtins.int]] = None,
                 sm_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 sm_url: Optional[pulumi.Input[builtins.str]] = None,
                 stack_id: Optional[pulumi.Input[builtins.int]] = None,
                 store_dashboard_sha256: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_cert: Optional[pulumi.Input[builtins.str]] = None,
                 tls_key: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        The provider type for the grafana package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] auth: API token, basic auth in the `username:password` format or `anonymous` (string literal). May alternatively be set via
               the `GRAFANA_AUTH` environment variable.
        :param pulumi.Input[builtins.str] ca_cert: Certificate CA bundle (file path or literal value) to use to verify the Grafana server's certificate. May alternatively
               be set via the `GRAFANA_CA_CERT` environment variable.
        :param pulumi.Input[builtins.str] cloud_access_policy_token: Access Policy Token for Grafana Cloud. May alternatively be set via the `GRAFANA_CLOUD_ACCESS_POLICY_TOKEN` environment
               variable.
        :param pulumi.Input[builtins.str] cloud_api_url: Grafana Cloud's API URL. May alternatively be set via the `GRAFANA_CLOUD_API_URL` environment variable.
        :param pulumi.Input[builtins.str] cloud_provider_access_token: A Grafana Cloud Provider access token. May alternatively be set via the `GRAFANA_CLOUD_PROVIDER_ACCESS_TOKEN`
               environment variable.
        :param pulumi.Input[builtins.str] cloud_provider_url: A Grafana Cloud Provider backend address. May alternatively be set via the `GRAFANA_CLOUD_PROVIDER_URL` environment
               variable.
        :param pulumi.Input[builtins.str] connections_api_access_token: A Grafana Connections API access token. May alternatively be set via the `GRAFANA_CONNECTIONS_API_ACCESS_TOKEN`
               environment variable.
        :param pulumi.Input[builtins.str] connections_api_url: A Grafana Connections API address. May alternatively be set via the `GRAFANA_CONNECTIONS_API_URL` environment variable.
        :param pulumi.Input[builtins.str] fleet_management_auth: A Grafana Fleet Management basic auth in the `username:password` format. May alternatively be set via the
               `GRAFANA_FLEET_MANAGEMENT_AUTH` environment variable.
        :param pulumi.Input[builtins.str] fleet_management_url: A Grafana Fleet Management API address. May alternatively be set via the `GRAFANA_FLEET_MANAGEMENT_URL` environment
               variable.
        :param pulumi.Input[builtins.str] frontend_o11y_api_access_token: A Grafana Frontend Observability API access token. May alternatively be set via the
               `GRAFANA_FRONTEND_O11Y_API_ACCESS_TOKEN` environment variable.
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] http_headers: Optional. HTTP headers mapping keys to values used for accessing the Grafana and Grafana Cloud APIs. May alternatively
               be set via the `GRAFANA_HTTP_HEADERS` environment variable in JSON format.
        :param pulumi.Input[builtins.bool] insecure_skip_verify: Skip TLS certificate verification. May alternatively be set via the `GRAFANA_INSECURE_SKIP_VERIFY` environment variable.
        :param pulumi.Input[builtins.str] k6_access_token: The k6 Cloud API token. May alternatively be set via the `GRAFANA_K6_ACCESS_TOKEN` environment variable.
        :param pulumi.Input[builtins.str] k6_url: The k6 Cloud API url. May alternatively be set via the `GRAFANA_K6_URL` environment variable.
        :param pulumi.Input[builtins.str] oncall_access_token: A Grafana OnCall access token. May alternatively be set via the `GRAFANA_ONCALL_ACCESS_TOKEN` environment variable.
        :param pulumi.Input[builtins.str] oncall_url: An Grafana OnCall backend address. May alternatively be set via the `GRAFANA_ONCALL_URL` environment variable.
        :param pulumi.Input[builtins.int] org_id: The Grafana org ID, if you are using a self-hosted OSS or enterprise Grafana instance. May alternatively be set via the
               `GRAFANA_ORG_ID` environment variable.
        :param pulumi.Input[builtins.int] retries: The amount of retries to use for Grafana API and Grafana Cloud API calls. May alternatively be set via the
               `GRAFANA_RETRIES` environment variable.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] retry_status_codes: The status codes to retry on for Grafana API and Grafana Cloud API calls. Use `x` as a digit wildcard. Defaults to 429
               and 5xx. May alternatively be set via the `GRAFANA_RETRY_STATUS_CODES` environment variable.
        :param pulumi.Input[builtins.int] retry_wait: The amount of time in seconds to wait between retries for Grafana API and Grafana Cloud API calls. May alternatively be
               set via the `GRAFANA_RETRY_WAIT` environment variable.
        :param pulumi.Input[builtins.str] sm_access_token: A Synthetic Monitoring access token. May alternatively be set via the `GRAFANA_SM_ACCESS_TOKEN` environment variable.
        :param pulumi.Input[builtins.int] stack_id: The Grafana stack ID, if you are using a Grafana Cloud stack. May alternatively be set via the `GRAFANA_STACK_ID`
               environment variable.
        :param pulumi.Input[builtins.bool] store_dashboard_sha256: Set to true if you want to save only the sha256sum instead of complete dashboard model JSON in the tfstate.
        :param pulumi.Input[builtins.str] tls_cert: Client TLS certificate (file path or literal value) to use to authenticate to the Grafana server. May alternatively be
               set via the `GRAFANA_TLS_CERT` environment variable.
        :param pulumi.Input[builtins.str] tls_key: Client TLS key (file path or literal value) to use to authenticate to the Grafana server. May alternatively be set via
               the `GRAFANA_TLS_KEY` environment variable.
        :param pulumi.Input[builtins.str] url: The root URL of a Grafana server. May alternatively be set via the `GRAFANA_URL` environment variable.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProviderArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The provider type for the grafana package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param ProviderArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProviderArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 auth: Optional[pulumi.Input[builtins.str]] = None,
                 ca_cert: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_access_policy_token: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_api_url: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_provider_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 cloud_provider_url: Optional[pulumi.Input[builtins.str]] = None,
                 connections_api_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 connections_api_url: Optional[pulumi.Input[builtins.str]] = None,
                 fleet_management_auth: Optional[pulumi.Input[builtins.str]] = None,
                 fleet_management_url: Optional[pulumi.Input[builtins.str]] = None,
                 frontend_o11y_api_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 http_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 insecure_skip_verify: Optional[pulumi.Input[builtins.bool]] = None,
                 k6_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 k6_url: Optional[pulumi.Input[builtins.str]] = None,
                 oncall_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 oncall_url: Optional[pulumi.Input[builtins.str]] = None,
                 org_id: Optional[pulumi.Input[builtins.int]] = None,
                 retries: Optional[pulumi.Input[builtins.int]] = None,
                 retry_status_codes: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 retry_wait: Optional[pulumi.Input[builtins.int]] = None,
                 sm_access_token: Optional[pulumi.Input[builtins.str]] = None,
                 sm_url: Optional[pulumi.Input[builtins.str]] = None,
                 stack_id: Optional[pulumi.Input[builtins.int]] = None,
                 store_dashboard_sha256: Optional[pulumi.Input[builtins.bool]] = None,
                 tls_cert: Optional[pulumi.Input[builtins.str]] = None,
                 tls_key: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProviderArgs.__new__(ProviderArgs)

            if auth is None:
                auth = _utilities.get_env('GRAFANA_AUTH')
            __props__.__dict__["auth"] = None if auth is None else pulumi.Output.secret(auth)
            if ca_cert is None:
                ca_cert = _utilities.get_env('GRAFANA_CA_CERT')
            __props__.__dict__["ca_cert"] = ca_cert
            if cloud_access_policy_token is None:
                cloud_access_policy_token = _utilities.get_env('GRAFANA_CLOUD_ACCESS_POLICY_TOKEN')
            __props__.__dict__["cloud_access_policy_token"] = None if cloud_access_policy_token is None else pulumi.Output.secret(cloud_access_policy_token)
            if cloud_api_url is None:
                cloud_api_url = _utilities.get_env('GRAFANA_CLOUD_API_URL')
            __props__.__dict__["cloud_api_url"] = cloud_api_url
            __props__.__dict__["cloud_provider_access_token"] = None if cloud_provider_access_token is None else pulumi.Output.secret(cloud_provider_access_token)
            __props__.__dict__["cloud_provider_url"] = cloud_provider_url
            __props__.__dict__["connections_api_access_token"] = None if connections_api_access_token is None else pulumi.Output.secret(connections_api_access_token)
            __props__.__dict__["connections_api_url"] = connections_api_url
            __props__.__dict__["fleet_management_auth"] = None if fleet_management_auth is None else pulumi.Output.secret(fleet_management_auth)
            __props__.__dict__["fleet_management_url"] = fleet_management_url
            __props__.__dict__["frontend_o11y_api_access_token"] = None if frontend_o11y_api_access_token is None else pulumi.Output.secret(frontend_o11y_api_access_token)
            __props__.__dict__["http_headers"] = pulumi.Output.secret(http_headers).apply(pulumi.runtime.to_json) if http_headers is not None else None
            if insecure_skip_verify is None:
                insecure_skip_verify = _utilities.get_env_bool('GRAFANA_INSECURE_SKIP_VERIFY')
            __props__.__dict__["insecure_skip_verify"] = pulumi.Output.from_input(insecure_skip_verify).apply(pulumi.runtime.to_json) if insecure_skip_verify is not None else None
            __props__.__dict__["k6_access_token"] = None if k6_access_token is None else pulumi.Output.secret(k6_access_token)
            __props__.__dict__["k6_url"] = k6_url
            if oncall_access_token is None:
                oncall_access_token = _utilities.get_env('GRAFANA_ONCALL_ACCESS_TOKEN')
            __props__.__dict__["oncall_access_token"] = None if oncall_access_token is None else pulumi.Output.secret(oncall_access_token)
            if oncall_url is None:
                oncall_url = _utilities.get_env('GRAFANA_ONCALL_URL')
            __props__.__dict__["oncall_url"] = oncall_url
            __props__.__dict__["org_id"] = pulumi.Output.from_input(org_id).apply(pulumi.runtime.to_json) if org_id is not None else None
            if retries is None:
                retries = _utilities.get_env_int('GRAFANA_RETRIES')
            __props__.__dict__["retries"] = pulumi.Output.from_input(retries).apply(pulumi.runtime.to_json) if retries is not None else None
            __props__.__dict__["retry_status_codes"] = pulumi.Output.from_input(retry_status_codes).apply(pulumi.runtime.to_json) if retry_status_codes is not None else None
            if retry_wait is None:
                retry_wait = _utilities.get_env_int('GRAFANA_RETRY_WAIT')
            __props__.__dict__["retry_wait"] = pulumi.Output.from_input(retry_wait).apply(pulumi.runtime.to_json) if retry_wait is not None else None
            if sm_access_token is None:
                sm_access_token = _utilities.get_env('GRAFANA_SM_ACCESS_TOKEN')
            __props__.__dict__["sm_access_token"] = None if sm_access_token is None else pulumi.Output.secret(sm_access_token)
            if sm_url is None:
                sm_url = _utilities.get_env('GRAFANA_SM_URL')
            __props__.__dict__["sm_url"] = sm_url
            __props__.__dict__["stack_id"] = pulumi.Output.from_input(stack_id).apply(pulumi.runtime.to_json) if stack_id is not None else None
            if store_dashboard_sha256 is None:
                store_dashboard_sha256 = _utilities.get_env_bool('GRAFANA_STORE_DASHBOARD_SHA256')
            __props__.__dict__["store_dashboard_sha256"] = pulumi.Output.from_input(store_dashboard_sha256).apply(pulumi.runtime.to_json) if store_dashboard_sha256 is not None else None
            if tls_cert is None:
                tls_cert = _utilities.get_env('GRAFANA_TLS_CERT')
            __props__.__dict__["tls_cert"] = tls_cert
            if tls_key is None:
                tls_key = _utilities.get_env('GRAFANA_TLS_KEY')
            __props__.__dict__["tls_key"] = None if tls_key is None else pulumi.Output.secret(tls_key)
            if url is None:
                url = _utilities.get_env('GRAFANA_URL')
            __props__.__dict__["url"] = url
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["auth", "cloudAccessPolicyToken", "cloudProviderAccessToken", "connectionsApiAccessToken", "fleetManagementAuth", "frontendO11yApiAccessToken", "k6AccessToken", "oncallAccessToken", "smAccessToken", "tlsKey"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Provider, __self__).__init__(
            'grafana',
            resource_name,
            __props__,
            opts)

    @property
    @pulumi.getter
    def auth(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        API token, basic auth in the `username:password` format or `anonymous` (string literal). May alternatively be set via
        the `GRAFANA_AUTH` environment variable.
        """
        return pulumi.get(self, "auth")

    @property
    @pulumi.getter(name="caCert")
    def ca_cert(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Certificate CA bundle (file path or literal value) to use to verify the Grafana server's certificate. May alternatively
        be set via the `GRAFANA_CA_CERT` environment variable.
        """
        return pulumi.get(self, "ca_cert")

    @property
    @pulumi.getter(name="cloudAccessPolicyToken")
    def cloud_access_policy_token(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Access Policy Token for Grafana Cloud. May alternatively be set via the `GRAFANA_CLOUD_ACCESS_POLICY_TOKEN` environment
        variable.
        """
        return pulumi.get(self, "cloud_access_policy_token")

    @property
    @pulumi.getter(name="cloudApiUrl")
    def cloud_api_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Grafana Cloud's API URL. May alternatively be set via the `GRAFANA_CLOUD_API_URL` environment variable.
        """
        return pulumi.get(self, "cloud_api_url")

    @property
    @pulumi.getter(name="cloudProviderAccessToken")
    def cloud_provider_access_token(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A Grafana Cloud Provider access token. May alternatively be set via the `GRAFANA_CLOUD_PROVIDER_ACCESS_TOKEN`
        environment variable.
        """
        return pulumi.get(self, "cloud_provider_access_token")

    @property
    @pulumi.getter(name="cloudProviderUrl")
    def cloud_provider_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A Grafana Cloud Provider backend address. May alternatively be set via the `GRAFANA_CLOUD_PROVIDER_URL` environment
        variable.
        """
        return pulumi.get(self, "cloud_provider_url")

    @property
    @pulumi.getter(name="connectionsApiAccessToken")
    def connections_api_access_token(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A Grafana Connections API access token. May alternatively be set via the `GRAFANA_CONNECTIONS_API_ACCESS_TOKEN`
        environment variable.
        """
        return pulumi.get(self, "connections_api_access_token")

    @property
    @pulumi.getter(name="connectionsApiUrl")
    def connections_api_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A Grafana Connections API address. May alternatively be set via the `GRAFANA_CONNECTIONS_API_URL` environment variable.
        """
        return pulumi.get(self, "connections_api_url")

    @property
    @pulumi.getter(name="fleetManagementAuth")
    def fleet_management_auth(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A Grafana Fleet Management basic auth in the `username:password` format. May alternatively be set via the
        `GRAFANA_FLEET_MANAGEMENT_AUTH` environment variable.
        """
        return pulumi.get(self, "fleet_management_auth")

    @property
    @pulumi.getter(name="fleetManagementUrl")
    def fleet_management_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A Grafana Fleet Management API address. May alternatively be set via the `GRAFANA_FLEET_MANAGEMENT_URL` environment
        variable.
        """
        return pulumi.get(self, "fleet_management_url")

    @property
    @pulumi.getter(name="frontendO11yApiAccessToken")
    def frontend_o11y_api_access_token(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A Grafana Frontend Observability API access token. May alternatively be set via the
        `GRAFANA_FRONTEND_O11Y_API_ACCESS_TOKEN` environment variable.
        """
        return pulumi.get(self, "frontend_o11y_api_access_token")

    @property
    @pulumi.getter(name="k6AccessToken")
    def k6_access_token(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The k6 Cloud API token. May alternatively be set via the `GRAFANA_K6_ACCESS_TOKEN` environment variable.
        """
        return pulumi.get(self, "k6_access_token")

    @property
    @pulumi.getter(name="k6Url")
    def k6_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The k6 Cloud API url. May alternatively be set via the `GRAFANA_K6_URL` environment variable.
        """
        return pulumi.get(self, "k6_url")

    @property
    @pulumi.getter(name="oncallAccessToken")
    def oncall_access_token(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A Grafana OnCall access token. May alternatively be set via the `GRAFANA_ONCALL_ACCESS_TOKEN` environment variable.
        """
        return pulumi.get(self, "oncall_access_token")

    @property
    @pulumi.getter(name="oncallUrl")
    def oncall_url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        An Grafana OnCall backend address. May alternatively be set via the `GRAFANA_ONCALL_URL` environment variable.
        """
        return pulumi.get(self, "oncall_url")

    @property
    @pulumi.getter(name="smAccessToken")
    def sm_access_token(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A Synthetic Monitoring access token. May alternatively be set via the `GRAFANA_SM_ACCESS_TOKEN` environment variable.
        """
        return pulumi.get(self, "sm_access_token")

    @property
    @pulumi.getter(name="smUrl")
    def sm_url(self) -> pulumi.Output[Optional[builtins.str]]:
        return pulumi.get(self, "sm_url")

    @property
    @pulumi.getter(name="tlsCert")
    def tls_cert(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Client TLS certificate (file path or literal value) to use to authenticate to the Grafana server. May alternatively be
        set via the `GRAFANA_TLS_CERT` environment variable.
        """
        return pulumi.get(self, "tls_cert")

    @property
    @pulumi.getter(name="tlsKey")
    def tls_key(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Client TLS key (file path or literal value) to use to authenticate to the Grafana server. May alternatively be set via
        the `GRAFANA_TLS_KEY` environment variable.
        """
        return pulumi.get(self, "tls_key")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The root URL of a Grafana server. May alternatively be set via the `GRAFANA_URL` environment variable.
        """
        return pulumi.get(self, "url")

    @pulumi.output_type
    class TerraformConfigResult:
        def __init__(__self__, result=None):
            if result and not isinstance(result, dict):
                raise TypeError("Expected argument 'result' to be a dict")
            pulumi.set(__self__, "result", result)

        @property
        @pulumi.getter
        def result(self) -> Mapping[str, Any]:
            return pulumi.get(self, "result")

    def terraform_config(__self__) -> pulumi.Output['Provider.TerraformConfigResult']:
        """
        This function returns a Terraform config object with terraform-namecased keys,to be used with the Terraform Module Provider.
        """
        __args__ = dict()
        __args__['__self__'] = __self__
        return pulumi.runtime.call('pulumi:providers:grafana/terraformConfig', __args__, res=__self__, typ=Provider.TerraformConfigResult)




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['OutgoingWebhookArgs', 'OutgoingWebhook']

@pulumi.input_type
class OutgoingWebhookArgs:
    def __init__(__self__, *,
                 url: pulumi.Input[builtins.str],
                 authorization_header: Optional[pulumi.Input[builtins.str]] = None,
                 data: Optional[pulumi.Input[builtins.str]] = None,
                 forward_whole_payload: Optional[pulumi.Input[builtins.bool]] = None,
                 headers: Optional[pulumi.Input[builtins.str]] = None,
                 http_method: Optional[pulumi.Input[builtins.str]] = None,
                 integration_filters: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 is_webhook_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 trigger_template: Optional[pulumi.Input[builtins.str]] = None,
                 trigger_type: Optional[pulumi.Input[builtins.str]] = None,
                 user: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a OutgoingWebhook resource.
        :param pulumi.Input[builtins.str] url: The webhook URL.
        :param pulumi.Input[builtins.str] authorization_header: The auth data of the webhook. Used in Authorization header instead of user/password auth.
        :param pulumi.Input[builtins.str] data: The data of the webhook.
        :param pulumi.Input[builtins.bool] forward_whole_payload: Toggle to send the entire webhook payload instead of using the values in the Data field.
        :param pulumi.Input[builtins.str] headers: Headers to add to the outgoing webhook request.
        :param pulumi.Input[builtins.str] http_method: The HTTP method used in the request made by the outgoing webhook. Defaults to `POST`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] integration_filters: Restricts the outgoing webhook to only trigger if the event came from a selected integration. If no integrations are selected the outgoing webhook will trigger for any integration.
        :param pulumi.Input[builtins.bool] is_webhook_enabled: Controls whether the outgoing webhook will trigger or is ignored. Defaults to `true`.
        :param pulumi.Input[builtins.str] name: The name of the outgoing webhook.
        :param pulumi.Input[builtins.str] password: The auth data of the webhook. Used for Basic authentication
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        :param pulumi.Input[builtins.str] trigger_template: A template used to dynamically determine whether the webhook should execute based on the content of the payload.
        :param pulumi.Input[builtins.str] trigger_type: The type of event that will cause this outgoing webhook to execute. The types of triggers are: `escalation`, `alert group created`, `acknowledge`, `resolve`, `silence`, `unsilence`, `unresolve`, `unacknowledge`. Defaults to `escalation`.
        :param pulumi.Input[builtins.str] user: Username to use when making the outgoing webhook request.
        """
        pulumi.set(__self__, "url", url)
        if authorization_header is not None:
            pulumi.set(__self__, "authorization_header", authorization_header)
        if data is not None:
            pulumi.set(__self__, "data", data)
        if forward_whole_payload is not None:
            pulumi.set(__self__, "forward_whole_payload", forward_whole_payload)
        if headers is not None:
            pulumi.set(__self__, "headers", headers)
        if http_method is not None:
            pulumi.set(__self__, "http_method", http_method)
        if integration_filters is not None:
            pulumi.set(__self__, "integration_filters", integration_filters)
        if is_webhook_enabled is not None:
            pulumi.set(__self__, "is_webhook_enabled", is_webhook_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if trigger_template is not None:
            pulumi.set(__self__, "trigger_template", trigger_template)
        if trigger_type is not None:
            pulumi.set(__self__, "trigger_type", trigger_type)
        if user is not None:
            pulumi.set(__self__, "user", user)

    @property
    @pulumi.getter
    def url(self) -> pulumi.Input[builtins.str]:
        """
        The webhook URL.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter(name="authorizationHeader")
    def authorization_header(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The auth data of the webhook. Used in Authorization header instead of user/password auth.
        """
        return pulumi.get(self, "authorization_header")

    @authorization_header.setter
    def authorization_header(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authorization_header", value)

    @property
    @pulumi.getter
    def data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The data of the webhook.
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "data", value)

    @property
    @pulumi.getter(name="forwardWholePayload")
    def forward_whole_payload(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Toggle to send the entire webhook payload instead of using the values in the Data field.
        """
        return pulumi.get(self, "forward_whole_payload")

    @forward_whole_payload.setter
    def forward_whole_payload(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "forward_whole_payload", value)

    @property
    @pulumi.getter
    def headers(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Headers to add to the outgoing webhook request.
        """
        return pulumi.get(self, "headers")

    @headers.setter
    def headers(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "headers", value)

    @property
    @pulumi.getter(name="httpMethod")
    def http_method(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The HTTP method used in the request made by the outgoing webhook. Defaults to `POST`.
        """
        return pulumi.get(self, "http_method")

    @http_method.setter
    def http_method(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "http_method", value)

    @property
    @pulumi.getter(name="integrationFilters")
    def integration_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Restricts the outgoing webhook to only trigger if the event came from a selected integration. If no integrations are selected the outgoing webhook will trigger for any integration.
        """
        return pulumi.get(self, "integration_filters")

    @integration_filters.setter
    def integration_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "integration_filters", value)

    @property
    @pulumi.getter(name="isWebhookEnabled")
    def is_webhook_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Controls whether the outgoing webhook will trigger or is ignored. Defaults to `true`.
        """
        return pulumi.get(self, "is_webhook_enabled")

    @is_webhook_enabled.setter
    def is_webhook_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_webhook_enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the outgoing webhook.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The auth data of the webhook. Used for Basic authentication
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter(name="triggerTemplate")
    def trigger_template(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A template used to dynamically determine whether the webhook should execute based on the content of the payload.
        """
        return pulumi.get(self, "trigger_template")

    @trigger_template.setter
    def trigger_template(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "trigger_template", value)

    @property
    @pulumi.getter(name="triggerType")
    def trigger_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of event that will cause this outgoing webhook to execute. The types of triggers are: `escalation`, `alert group created`, `acknowledge`, `resolve`, `silence`, `unsilence`, `unresolve`, `unacknowledge`. Defaults to `escalation`.
        """
        return pulumi.get(self, "trigger_type")

    @trigger_type.setter
    def trigger_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "trigger_type", value)

    @property
    @pulumi.getter
    def user(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Username to use when making the outgoing webhook request.
        """
        return pulumi.get(self, "user")

    @user.setter
    def user(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user", value)


@pulumi.input_type
class _OutgoingWebhookState:
    def __init__(__self__, *,
                 authorization_header: Optional[pulumi.Input[builtins.str]] = None,
                 data: Optional[pulumi.Input[builtins.str]] = None,
                 forward_whole_payload: Optional[pulumi.Input[builtins.bool]] = None,
                 headers: Optional[pulumi.Input[builtins.str]] = None,
                 http_method: Optional[pulumi.Input[builtins.str]] = None,
                 integration_filters: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 is_webhook_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 trigger_template: Optional[pulumi.Input[builtins.str]] = None,
                 trigger_type: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 user: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering OutgoingWebhook resources.
        :param pulumi.Input[builtins.str] authorization_header: The auth data of the webhook. Used in Authorization header instead of user/password auth.
        :param pulumi.Input[builtins.str] data: The data of the webhook.
        :param pulumi.Input[builtins.bool] forward_whole_payload: Toggle to send the entire webhook payload instead of using the values in the Data field.
        :param pulumi.Input[builtins.str] headers: Headers to add to the outgoing webhook request.
        :param pulumi.Input[builtins.str] http_method: The HTTP method used in the request made by the outgoing webhook. Defaults to `POST`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] integration_filters: Restricts the outgoing webhook to only trigger if the event came from a selected integration. If no integrations are selected the outgoing webhook will trigger for any integration.
        :param pulumi.Input[builtins.bool] is_webhook_enabled: Controls whether the outgoing webhook will trigger or is ignored. Defaults to `true`.
        :param pulumi.Input[builtins.str] name: The name of the outgoing webhook.
        :param pulumi.Input[builtins.str] password: The auth data of the webhook. Used for Basic authentication
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        :param pulumi.Input[builtins.str] trigger_template: A template used to dynamically determine whether the webhook should execute based on the content of the payload.
        :param pulumi.Input[builtins.str] trigger_type: The type of event that will cause this outgoing webhook to execute. The types of triggers are: `escalation`, `alert group created`, `acknowledge`, `resolve`, `silence`, `unsilence`, `unresolve`, `unacknowledge`. Defaults to `escalation`.
        :param pulumi.Input[builtins.str] url: The webhook URL.
        :param pulumi.Input[builtins.str] user: Username to use when making the outgoing webhook request.
        """
        if authorization_header is not None:
            pulumi.set(__self__, "authorization_header", authorization_header)
        if data is not None:
            pulumi.set(__self__, "data", data)
        if forward_whole_payload is not None:
            pulumi.set(__self__, "forward_whole_payload", forward_whole_payload)
        if headers is not None:
            pulumi.set(__self__, "headers", headers)
        if http_method is not None:
            pulumi.set(__self__, "http_method", http_method)
        if integration_filters is not None:
            pulumi.set(__self__, "integration_filters", integration_filters)
        if is_webhook_enabled is not None:
            pulumi.set(__self__, "is_webhook_enabled", is_webhook_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if trigger_template is not None:
            pulumi.set(__self__, "trigger_template", trigger_template)
        if trigger_type is not None:
            pulumi.set(__self__, "trigger_type", trigger_type)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if user is not None:
            pulumi.set(__self__, "user", user)

    @property
    @pulumi.getter(name="authorizationHeader")
    def authorization_header(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The auth data of the webhook. Used in Authorization header instead of user/password auth.
        """
        return pulumi.get(self, "authorization_header")

    @authorization_header.setter
    def authorization_header(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "authorization_header", value)

    @property
    @pulumi.getter
    def data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The data of the webhook.
        """
        return pulumi.get(self, "data")

    @data.setter
    def data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "data", value)

    @property
    @pulumi.getter(name="forwardWholePayload")
    def forward_whole_payload(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Toggle to send the entire webhook payload instead of using the values in the Data field.
        """
        return pulumi.get(self, "forward_whole_payload")

    @forward_whole_payload.setter
    def forward_whole_payload(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "forward_whole_payload", value)

    @property
    @pulumi.getter
    def headers(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Headers to add to the outgoing webhook request.
        """
        return pulumi.get(self, "headers")

    @headers.setter
    def headers(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "headers", value)

    @property
    @pulumi.getter(name="httpMethod")
    def http_method(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The HTTP method used in the request made by the outgoing webhook. Defaults to `POST`.
        """
        return pulumi.get(self, "http_method")

    @http_method.setter
    def http_method(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "http_method", value)

    @property
    @pulumi.getter(name="integrationFilters")
    def integration_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Restricts the outgoing webhook to only trigger if the event came from a selected integration. If no integrations are selected the outgoing webhook will trigger for any integration.
        """
        return pulumi.get(self, "integration_filters")

    @integration_filters.setter
    def integration_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "integration_filters", value)

    @property
    @pulumi.getter(name="isWebhookEnabled")
    def is_webhook_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Controls whether the outgoing webhook will trigger or is ignored. Defaults to `true`.
        """
        return pulumi.get(self, "is_webhook_enabled")

    @is_webhook_enabled.setter
    def is_webhook_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_webhook_enabled", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the outgoing webhook.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The auth data of the webhook. Used for Basic authentication
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "team_id", value)

    @property
    @pulumi.getter(name="triggerTemplate")
    def trigger_template(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A template used to dynamically determine whether the webhook should execute based on the content of the payload.
        """
        return pulumi.get(self, "trigger_template")

    @trigger_template.setter
    def trigger_template(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "trigger_template", value)

    @property
    @pulumi.getter(name="triggerType")
    def trigger_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The type of event that will cause this outgoing webhook to execute. The types of triggers are: `escalation`, `alert group created`, `acknowledge`, `resolve`, `silence`, `unsilence`, `unresolve`, `unacknowledge`. Defaults to `escalation`.
        """
        return pulumi.get(self, "trigger_type")

    @trigger_type.setter
    def trigger_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "trigger_type", value)

    @property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The webhook URL.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "url", value)

    @property
    @pulumi.getter
    def user(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Username to use when making the outgoing webhook request.
        """
        return pulumi.get(self, "user")

    @user.setter
    def user(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user", value)


@pulumi.type_token("grafana:onCall/outgoingWebhook:OutgoingWebhook")
class OutgoingWebhook(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authorization_header: Optional[pulumi.Input[builtins.str]] = None,
                 data: Optional[pulumi.Input[builtins.str]] = None,
                 forward_whole_payload: Optional[pulumi.Input[builtins.bool]] = None,
                 headers: Optional[pulumi.Input[builtins.str]] = None,
                 http_method: Optional[pulumi.Input[builtins.str]] = None,
                 integration_filters: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 is_webhook_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 trigger_template: Optional[pulumi.Input[builtins.str]] = None,
                 trigger_type: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 user: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/outgoing_webhooks/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_grafana as grafana
        import pulumiverse_grafana as grafana

        my_team = grafana.oss.get_team(name="my team")
        my_team_get_team = grafana.onCall.get_team(name=my_team.name)
        test_acc_outgoing_webhook = grafana.on_call.OutgoingWebhook("test-acc-outgoing_webhook",
            name="my outgoing webhook",
            url="https://example.com/",
            team_id=my_team_get_team.id)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:onCall/outgoingWebhook:OutgoingWebhook name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authorization_header: The auth data of the webhook. Used in Authorization header instead of user/password auth.
        :param pulumi.Input[builtins.str] data: The data of the webhook.
        :param pulumi.Input[builtins.bool] forward_whole_payload: Toggle to send the entire webhook payload instead of using the values in the Data field.
        :param pulumi.Input[builtins.str] headers: Headers to add to the outgoing webhook request.
        :param pulumi.Input[builtins.str] http_method: The HTTP method used in the request made by the outgoing webhook. Defaults to `POST`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] integration_filters: Restricts the outgoing webhook to only trigger if the event came from a selected integration. If no integrations are selected the outgoing webhook will trigger for any integration.
        :param pulumi.Input[builtins.bool] is_webhook_enabled: Controls whether the outgoing webhook will trigger or is ignored. Defaults to `true`.
        :param pulumi.Input[builtins.str] name: The name of the outgoing webhook.
        :param pulumi.Input[builtins.str] password: The auth data of the webhook. Used for Basic authentication
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        :param pulumi.Input[builtins.str] trigger_template: A template used to dynamically determine whether the webhook should execute based on the content of the payload.
        :param pulumi.Input[builtins.str] trigger_type: The type of event that will cause this outgoing webhook to execute. The types of triggers are: `escalation`, `alert group created`, `acknowledge`, `resolve`, `silence`, `unsilence`, `unresolve`, `unacknowledge`. Defaults to `escalation`.
        :param pulumi.Input[builtins.str] url: The webhook URL.
        :param pulumi.Input[builtins.str] user: Username to use when making the outgoing webhook request.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: OutgoingWebhookArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        * [HTTP API](https://grafana.com/docs/oncall/latest/oncall-api-reference/outgoing_webhooks/)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_grafana as grafana
        import pulumiverse_grafana as grafana

        my_team = grafana.oss.get_team(name="my team")
        my_team_get_team = grafana.onCall.get_team(name=my_team.name)
        test_acc_outgoing_webhook = grafana.on_call.OutgoingWebhook("test-acc-outgoing_webhook",
            name="my outgoing webhook",
            url="https://example.com/",
            team_id=my_team_get_team.id)
        ```

        ## Import

        ```sh
        $ pulumi import grafana:onCall/outgoingWebhook:OutgoingWebhook name "{{ id }}"
        ```

        :param str resource_name: The name of the resource.
        :param OutgoingWebhookArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(OutgoingWebhookArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 authorization_header: Optional[pulumi.Input[builtins.str]] = None,
                 data: Optional[pulumi.Input[builtins.str]] = None,
                 forward_whole_payload: Optional[pulumi.Input[builtins.bool]] = None,
                 headers: Optional[pulumi.Input[builtins.str]] = None,
                 http_method: Optional[pulumi.Input[builtins.str]] = None,
                 integration_filters: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 is_webhook_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 team_id: Optional[pulumi.Input[builtins.str]] = None,
                 trigger_template: Optional[pulumi.Input[builtins.str]] = None,
                 trigger_type: Optional[pulumi.Input[builtins.str]] = None,
                 url: Optional[pulumi.Input[builtins.str]] = None,
                 user: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = OutgoingWebhookArgs.__new__(OutgoingWebhookArgs)

            __props__.__dict__["authorization_header"] = None if authorization_header is None else pulumi.Output.secret(authorization_header)
            __props__.__dict__["data"] = data
            __props__.__dict__["forward_whole_payload"] = forward_whole_payload
            __props__.__dict__["headers"] = headers
            __props__.__dict__["http_method"] = http_method
            __props__.__dict__["integration_filters"] = integration_filters
            __props__.__dict__["is_webhook_enabled"] = is_webhook_enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["password"] = None if password is None else pulumi.Output.secret(password)
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["trigger_template"] = trigger_template
            __props__.__dict__["trigger_type"] = trigger_type
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["user"] = user
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="grafana:index/oncallOutgoingWebhook:OncallOutgoingWebhook")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["authorizationHeader", "password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(OutgoingWebhook, __self__).__init__(
            'grafana:onCall/outgoingWebhook:OutgoingWebhook',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            authorization_header: Optional[pulumi.Input[builtins.str]] = None,
            data: Optional[pulumi.Input[builtins.str]] = None,
            forward_whole_payload: Optional[pulumi.Input[builtins.bool]] = None,
            headers: Optional[pulumi.Input[builtins.str]] = None,
            http_method: Optional[pulumi.Input[builtins.str]] = None,
            integration_filters: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            is_webhook_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            team_id: Optional[pulumi.Input[builtins.str]] = None,
            trigger_template: Optional[pulumi.Input[builtins.str]] = None,
            trigger_type: Optional[pulumi.Input[builtins.str]] = None,
            url: Optional[pulumi.Input[builtins.str]] = None,
            user: Optional[pulumi.Input[builtins.str]] = None) -> 'OutgoingWebhook':
        """
        Get an existing OutgoingWebhook resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] authorization_header: The auth data of the webhook. Used in Authorization header instead of user/password auth.
        :param pulumi.Input[builtins.str] data: The data of the webhook.
        :param pulumi.Input[builtins.bool] forward_whole_payload: Toggle to send the entire webhook payload instead of using the values in the Data field.
        :param pulumi.Input[builtins.str] headers: Headers to add to the outgoing webhook request.
        :param pulumi.Input[builtins.str] http_method: The HTTP method used in the request made by the outgoing webhook. Defaults to `POST`.
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] integration_filters: Restricts the outgoing webhook to only trigger if the event came from a selected integration. If no integrations are selected the outgoing webhook will trigger for any integration.
        :param pulumi.Input[builtins.bool] is_webhook_enabled: Controls whether the outgoing webhook will trigger or is ignored. Defaults to `true`.
        :param pulumi.Input[builtins.str] name: The name of the outgoing webhook.
        :param pulumi.Input[builtins.str] password: The auth data of the webhook. Used for Basic authentication
        :param pulumi.Input[builtins.str] team_id: The ID of the OnCall team (using the `on_call_get_team` datasource).
        :param pulumi.Input[builtins.str] trigger_template: A template used to dynamically determine whether the webhook should execute based on the content of the payload.
        :param pulumi.Input[builtins.str] trigger_type: The type of event that will cause this outgoing webhook to execute. The types of triggers are: `escalation`, `alert group created`, `acknowledge`, `resolve`, `silence`, `unsilence`, `unresolve`, `unacknowledge`. Defaults to `escalation`.
        :param pulumi.Input[builtins.str] url: The webhook URL.
        :param pulumi.Input[builtins.str] user: Username to use when making the outgoing webhook request.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _OutgoingWebhookState.__new__(_OutgoingWebhookState)

        __props__.__dict__["authorization_header"] = authorization_header
        __props__.__dict__["data"] = data
        __props__.__dict__["forward_whole_payload"] = forward_whole_payload
        __props__.__dict__["headers"] = headers
        __props__.__dict__["http_method"] = http_method
        __props__.__dict__["integration_filters"] = integration_filters
        __props__.__dict__["is_webhook_enabled"] = is_webhook_enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["password"] = password
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["trigger_template"] = trigger_template
        __props__.__dict__["trigger_type"] = trigger_type
        __props__.__dict__["url"] = url
        __props__.__dict__["user"] = user
        return OutgoingWebhook(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="authorizationHeader")
    def authorization_header(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The auth data of the webhook. Used in Authorization header instead of user/password auth.
        """
        return pulumi.get(self, "authorization_header")

    @property
    @pulumi.getter
    def data(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The data of the webhook.
        """
        return pulumi.get(self, "data")

    @property
    @pulumi.getter(name="forwardWholePayload")
    def forward_whole_payload(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Toggle to send the entire webhook payload instead of using the values in the Data field.
        """
        return pulumi.get(self, "forward_whole_payload")

    @property
    @pulumi.getter
    def headers(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Headers to add to the outgoing webhook request.
        """
        return pulumi.get(self, "headers")

    @property
    @pulumi.getter(name="httpMethod")
    def http_method(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The HTTP method used in the request made by the outgoing webhook. Defaults to `POST`.
        """
        return pulumi.get(self, "http_method")

    @property
    @pulumi.getter(name="integrationFilters")
    def integration_filters(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Restricts the outgoing webhook to only trigger if the event came from a selected integration. If no integrations are selected the outgoing webhook will trigger for any integration.
        """
        return pulumi.get(self, "integration_filters")

    @property
    @pulumi.getter(name="isWebhookEnabled")
    def is_webhook_enabled(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Controls whether the outgoing webhook will trigger or is ignored. Defaults to `true`.
        """
        return pulumi.get(self, "is_webhook_enabled")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the outgoing webhook.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The auth data of the webhook. Used for Basic authentication
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The ID of the OnCall team (using the `on_call_get_team` datasource).
        """
        return pulumi.get(self, "team_id")

    @property
    @pulumi.getter(name="triggerTemplate")
    def trigger_template(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A template used to dynamically determine whether the webhook should execute based on the content of the payload.
        """
        return pulumi.get(self, "trigger_template")

    @property
    @pulumi.getter(name="triggerType")
    def trigger_type(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        The type of event that will cause this outgoing webhook to execute. The types of triggers are: `escalation`, `alert group created`, `acknowledge`, `resolve`, `silence`, `unsilence`, `unresolve`, `unacknowledge`. Defaults to `escalation`.
        """
        return pulumi.get(self, "trigger_type")

    @property
    @pulumi.getter
    def url(self) -> pulumi.Output[builtins.str]:
        """
        The webhook URL.
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def user(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Username to use when making the outgoing webhook request.
        """
        return pulumi.get(self, "user")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetAwsAccountResult',
    'AwaitableGetAwsAccountResult',
    'get_aws_account',
    'get_aws_account_output',
]

@pulumi.output_type
class GetAwsAccountResult:
    """
    A collection of values returned by getAwsAccount.
    """
    def __init__(__self__, id=None, name=None, regions=None, resource_id=None, role_arn=None, stack_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if resource_id and not isinstance(resource_id, str):
            raise TypeError("Expected argument 'resource_id' to be a str")
        pulumi.set(__self__, "resource_id", resource_id)
        if role_arn and not isinstance(role_arn, str):
            raise TypeError("Expected argument 'role_arn' to be a str")
        pulumi.set(__self__, "role_arn", role_arn)
        if stack_id and not isinstance(stack_id, str):
            raise TypeError("Expected argument 'stack_id' to be a str")
        pulumi.set(__self__, "stack_id", stack_id)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        An optional human-readable name for this AWS Account resource.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[builtins.str]:
        """
        A set of regions that this AWS Account resource applies to.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> builtins.str:
        """
        The ID given by the Grafana Cloud Provider API to this AWS Account resource.
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="roleArn")
    def role_arn(self) -> builtins.str:
        """
        An IAM Role ARN string to represent with this AWS Account resource.
        """
        return pulumi.get(self, "role_arn")

    @property
    @pulumi.getter(name="stackId")
    def stack_id(self) -> builtins.str:
        return pulumi.get(self, "stack_id")


class AwaitableGetAwsAccountResult(GetAwsAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAwsAccountResult(
            id=self.id,
            name=self.name,
            regions=self.regions,
            resource_id=self.resource_id,
            role_arn=self.role_arn,
            stack_id=self.stack_id)


def get_aws_account(resource_id: Optional[builtins.str] = None,
                    stack_id: Optional[builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAwsAccountResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test = grafana.cloud.get_stack(slug="gcloudstacktest")
    test_aws_account = grafana.cloud_provider.AwsAccount("test",
        stack_id=test.id,
        role_arn=test_aws_iam_role["arn"],
        regions=[
            "us-east-2",
            "eu-west-3",
        ])
    test_get_aws_account = test_aws_account.resource_id.apply(lambda resource_id: grafana.cloudProvider.get_aws_account(stack_id=test.id,
        resource_id=resource_id))
    ```


    :param builtins.str resource_id: The ID given by the Grafana Cloud Provider API to this AWS Account resource.
    """
    __args__ = dict()
    __args__['resourceId'] = resource_id
    __args__['stackId'] = stack_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('grafana:cloudProvider/getAwsAccount:getAwsAccount', __args__, opts=opts, typ=GetAwsAccountResult).value

    return AwaitableGetAwsAccountResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        regions=pulumi.get(__ret__, 'regions'),
        resource_id=pulumi.get(__ret__, 'resource_id'),
        role_arn=pulumi.get(__ret__, 'role_arn'),
        stack_id=pulumi.get(__ret__, 'stack_id'))
def get_aws_account_output(resource_id: Optional[pulumi.Input[builtins.str]] = None,
                           stack_id: Optional[pulumi.Input[builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAwsAccountResult]:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_grafana as grafana
    import pulumiverse_grafana as grafana

    test = grafana.cloud.get_stack(slug="gcloudstacktest")
    test_aws_account = grafana.cloud_provider.AwsAccount("test",
        stack_id=test.id,
        role_arn=test_aws_iam_role["arn"],
        regions=[
            "us-east-2",
            "eu-west-3",
        ])
    test_get_aws_account = test_aws_account.resource_id.apply(lambda resource_id: grafana.cloudProvider.get_aws_account(stack_id=test.id,
        resource_id=resource_id))
    ```


    :param builtins.str resource_id: The ID given by the Grafana Cloud Provider API to this AWS Account resource.
    """
    __args__ = dict()
    __args__['resourceId'] = resource_id
    __args__['stackId'] = stack_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('grafana:cloudProvider/getAwsAccount:getAwsAccount', __args__, opts=opts, typ=GetAwsAccountResult)
    return __ret__.apply(lambda __response__: GetAwsAccountResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        regions=pulumi.get(__response__, 'regions'),
        resource_id=pulumi.get(__response__, 'resource_id'),
        role_arn=pulumi.get(__response__, 'role_arn'),
        stack_id=pulumi.get(__response__, 'stack_id')))
